#
# spec file for package php-redis
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define pkg_name    redis

%define flavor php7%{nil}
%if "%{flavor}" == "" || (0%{?suse_version} >= 1550 && "%{flavor}" == "php7")
%define php_name php
ExclusiveArch:  do-not-build
%else
%define php_name %{flavor}
%endif
%if 0%{?suse_version} <= 1500
%define php_extdir  %(%{__php_config} --extension-dir)
%define php_cfgdir  %{_sysconfdir}/%{php_name}/conf.d
%endif

Name:           %{php_name}-%{pkg_name}
Version:        5.3.7
Release:        bp154.2.1
Summary:        API for communicating with Redis servers
License:        PHP-3.01
URL:            https://pecl.php.net/package/%{pkg_name}
Source0:        https://pecl.php.net/get/%{pkg_name}-%{version}.tgz
Source1:        %{pkg_name}.ini
Source2:        php-%{pkg_name}-rpmlintrc
BuildRequires:  %{php_name}-devel
BuildRequires:  re2c
Requires:       php(api) = %{php_core_api}
Requires:       php(zend-abi) = %{php_zend_api}
Provides:       php-%{pkg_name} = %{version}
Obsoletes:      php-%{pkg_name} < %{version}

%description
This extension provides an API for communicating with Redis servers

%prep
%setup -q -n %{pkg_name}-%{version}
sed -i 's|CONFIG_FILE=`tempfile`|CONFIG_FILE=`mktemp`|' tests/mkring.sh

%build
export CFLAGS="%{optflags} -fvisibility=hidden"
%{__phpize}
%configure
%make_build

%check
%make_build PHP_EXECUTABLE=%{__php} NO_INTERACTION=1 test

%install
%make_install INSTALL_ROOT=%{buildroot}
mkdir -p %{buildroot}%{php_cfgdir}
install -pm0644 %{SOURCE1} %{buildroot}%{php_cfgdir}/%{pkg_name}.ini

%files
%license COPYING
%doc CREDITS README.markdown
%config(noreplace) %{php_cfgdir}/%{pkg_name}.ini
%{php_extdir}/%{pkg_name}.so

%changelog
* Sat Dec 10 2022 Arjen de Korte <suse+build@de-korte.org>
- Remove php7 build for Tumbleweed (PHP 7.4 has reached EOL)
* Thu Feb 17 2022 Илья Индиго <ilya@ilya.pp.ua>
- Updated to 5.3.7
  * https://pecl.php.net/package-changelog.php?package=redis&release=5.3.7
  * Fixed RedisArray::[hsz]scan and tests.
  * Fixed RedisArray::scan.
  * Fixed LZF decompression logic.
* Tue Jan 25 2022 Arjen de Korte <suse+build@de-korte.org>
- Updated to 5.3.6
  * Fix a segfault in RedisArray::del
* Sun Dec 19 2021 Илья Индиго <ilya@ilya.pp.ua>
- Updated to 5.3.5
  * https://pecl.php.net/package-changelog.php?package=redis&release=5.3.5
  * Added experimental support for detecting a dirty connection.
  * Fixed RedisArray constructor bug.
  * Fixed segfault in redis_setoption_handler.
  * Fixed masters array in the event of a cluster failover.
  * Fixed 32 bit type error.
  * Fixed radix character in certain locales.
  * Fixed ZSTD Validation.
* Wed Mar 24 2021 Arjen de Korte <suse+build@de-korte.org>
- Update to 5.3.4
  * Fix multi/pipeline segfault on Apple silicon
  * Pass compression flag on HMGET in RedisCluster
  * Abide by ZSTD error return constants
  * Fix timing related CI session tests
* Wed Feb 17 2021 Илья Индиго <ilya@ilya.pp.ua>
- Refresh spec-file via spec-cleaner.
* Wed Feb 17 2021 Arjen de Korte <suse+build@de-korte.org>
- Use _multibuild to also build for php8
- Use php_cfgdir and php_extdir macros to determine location of files
* Tue Feb  2 2021 Arjen de Korte <suse+build@de-korte.org>
- Update to 5.3.3
  * Fix PHP8 Windows includes
  * Fix hash ops for php 8.0.1
  * Disable cloning Redis and RedisCluster objects
* Fri Jan 22 2021 Илья Индиго <ilya@ilya.pp.ua>
- Remove BuildRequires:php7-json (don't need in php7, but in php8 work in core).
* Thu Oct 22 2020 Arjen de Korte <suse+build@de-korte.org>
- Update to 5.3.2
  * Use "%%.17g" sprintf format for doubles as done in Redis server.
  * Allow to pass NULL as RedisCluster stream context options.
  * Verify SET options are strings before testing them as strings
  * Fix cluster segfault when dealing with NULL multi bulk replies
    in RedisCluster
  * Fix xReadGroup() must return message id
  * Fix memory leak in rediscluster session handler
  * Fix XInfo() returns false if the stream is empty
  * Relax requirements on set's expire argument
  * Refactor redis_sock_check_liveness
  * PHP8 compatibility
  * Update documentation
  * Add Redis::OPT_NULL_MULTIBULK_AS_NULL setting to treat NULL
    multi bulk replies as NULL instead of [].
  * Allow to specify stream context for rediscluster session handler
  * Add new parameter to RedisCluster to specify stream ssl/tls
    context.
  * Add new parameter to RedisSentinel to specify auth information
* Wed Jul  8 2020 Илья Индиго <ilya@ilya.pp.ua>
- Update to 5.3.1
  * https://pecl.php.net/package-changelog.php?package=redis&release=5.3.1
  * Properly clean up on session start failure.
  * Treat NULL as a failure for redis_extract_auth_info.
  * Don't dereference a NULL zend_string or efree one.
  * Fix config.m4 messages and test for and include php_hash.h.
* Fri Jul  3 2020 Илья Индиго <ilya@ilya.pp.ua>
- Update to 5.3.0
  * https://pecl.php.net/package-changelog.php?package=redis&release=5.3.0
  * Support for Redis 6 ACLs.
  * LZ4 Compression.
  * Support for new Redis 6 arguments.
  * Support for TLS connections.
  * New option Redis::SCAN_PREFIX, Redis::SCAN_NOPREFIX.
  * Configurable unit test authentication arguments.
  * Improved cluster slot caching mechanism to fix a couple
    of bugs and make it more efficient.
  * Stop calling Redis constructor when creating a RedisArray.
  * Use ZEND_LONG_FMT instead of system `long`.
  * Use long for SCAN iteration to fix potential overflow.
  * Avoid use-after-free of RediSock.
  * Use the portable `ZEND_LONG_FORMAT` family
    instead of C format specifiers.
  * PHP 8 compatibility.
* Wed May  6 2020 Johannes Weberhofer <jweberhofer@weberhofer.at>
- Update to 5.2.2
  * https://pecl.php.net/package-changelog.php?package=redis&release=5.2.2
    This is a bugfix release that contains a fix for authentication
    when using persistent connections, and an option to make the
    ECHO challenge response logic optional.
  * Inexpensive liveness check, and making ECHO optional [56898f81] (Pavlo Yatsukhnenko)
  * Move `AUTH` to `redis_sock_server_open` [80f2529b](Pavlo Yatsukhnenko)
* Fri Mar 27 2020 Илья Индиго <ilya@ilya.pp.ua>
- Update to 5.2.1
  * https://pecl.php.net/package-changelog.php?package=redis&release=5.2.1
  * Fix arginfo for Redis::zadd.
  * Fix segfault on closing persistent stream.
* Wed Mar  4 2020 Илья Индиго <ilya@ilya.pp.ua>
- Update to 5.2.0
  * https://pecl.php.net/package-changelog.php?package=redis&release=5.2.0
  * Include RedisSentinelTest.php in package.xml!
  * Fix -Wmaybe-uninitialized warning.
  * Fix improper destructor when zipping values and scores.
  * Use php_rand instead of php_mt_rand for liveness challenge string.
  * Initial support for RedisSentinel.
  * Fix for ASK redirections.
  * Create specific 'test skipped' exception.
  * Fixed memory leaks in RedisCluster.
  * Fixes for session lifetime values that underflow or overflow.
  * Enables slot caching for Redis Cluster.
  * Support TYPE argument for SCAN.
  * Added challenge/response mechanism for persistent connections.
* Fri Nov 29 2019 Илья Индиго <ilya@ilya.pp.ua>
- Update to 5.1.1
  * https://pecl.php.net/package-changelog.php?package=redis&release=5.1.1
  * Fix fail to connect to redis through unix socket.
  * Documentation improvements.
* Sat Nov  2 2019 Илья Индиго <ilya@ilya.pp.ua>
- Update to 5.1.0
  * https://pecl.php.net/package-changelog.php?package=redis&release=5.1.0
  * Fix regression for multihost_distribute_call added in 112c77e3.
  * Fix regression for conntecting to unix sockets with relative path
    added in 1f41da64.
  * Fix unix-socket detection logic broken in 418428fa.
  * Fix memory leak and bug with getLastError for redis_mbulk_reply_assoc
    and redis_mbulk_reply_zipped.
  * Fix bug with password contain "#" for redis_session.
  * Add optional support for Zstd compression, using --enable-redis-ztsd.
    This requires libzstd version >= 1.3.0.
  * Fix overallocation in RedisCluster directed node commands.
  * Also attach slaves when caching cluster slots.
  * Use zend_register_persistent_resource_ex for connection pooling.
  * Refactor redis_session.
  * Documentation improvements.
  * Fix missing null byte in PHP_MINFO_FUNCTION.
  * Remove dead code generic_unsubscribe_cmd.
  * Add documentation for zpopmin and zpopmax.
  * Allow to specify scheme for session handler.
* Wed Aug  7 2019 Илья Индиго <ilya@ilya.pp.ua>
- Refresh spec-file with manual optmizations
  * Remove version limit from BuildRequires:php7-devel (no actual).
  * Remove BuildRequires:php7-soap (no needed).
  * Add BuildRequires:php7-json (need for tests, but still does not load).
  * Add %%make_build and %%make_install macros.
- Update to 5.0.2
  * https://pecl.php.net/package-changelog.php?package=redis&release=5.0.2
  * RedisCluster segfaults after second connection with cache_slots enabled.
  * Cleanup TSRMLS_* usage.
  * Replace ulong with zend_ulong.
  * Replace uint with uint32_t.
  * Fix regression for conntecting to ports > 32767.
  * RedisCluster segfaults after second connection with cache_slots enabled.
  * Documentation improvements.
* Tue Jul  2 2019 Johannes Weberhofer <jweberhofer@weberhofer.at>
- Update to 5.0.0
  This release contains important improvements and breaking changes.
  The most interesting are: drop PHP5 support, RedisCluster slots caching,
  JSON and msgpack serializers, soft deprecation of non-Redis commands.
  * Remove HAVE_SPL
  * Allow compilation without JSON serialization enabled and fixes for
    deprecated helper methods.
  * Enable connection pooling by default
  * Soft deprecate methods that aren't actually Redis commands
  * Enable pooling for cluster slave nodes
  * xInfo response format
  * Make the XREADGROUP optional COUNT and BLOCK arguments nullable
  * Allow PING to take an optional argument
  * Allow ZRANGE to be called either with `true` or `['withscores' => true]`
  * Allow to specify server address as schema://host
  * Allow persistent_id to be passed as NULL with strict_types enabled
  * Add server address to exception message
  * Adds OPT_REPLY_LITERAL for rawCommand and EVAL
  * JSON serializer
  * Add support for STREAM to the type command
  * Fix TypeError when using built-in constants in `setOption`
  * Handle references in MGET
  * msgpack serializer
  * Add Cluster slots caching
  * Drop PHP5 support
  * Documentation improvements
* Fri Mar 15 2019 Johannes Weberhofer <jweberhofer@weberhofer.at>
- Update to 4.3.0
  * Proper persistent connections pooling implementation
  * RedisArray auth
  * Use zend_string for storing key
  * Add ZPOPMAX and ZPOPMIN support
  * Implement GEORADIUS_RO and GEORADIUSBYMEMBER_RO
  * Add callback parameter to subscribe/psubscribe arginfo
  * Don't check the number affected keys in PS_UPDATE_TIMESTAMP_FUNC
  * Xgroup updates
  * RedisCluster auth
  * Cancel pipeline mode without executing commands
  * Use zend_string for pipeline_cmd
  * Different key hashing algorithms from hash extension
  * Breaking the lock acquire loop in case of network problems
  * Implement consistent hashing algorithm for RedisArray
  * Use zend_string for storing RedisArray hosts
  * Update lzf_compress to be compatible with PECL lzf extension
  * Fix RedisCluster keys memory leak
  * Directly use return_value in RedisCluster::keys method
  * Fix segfault in Redis Cluster with inconsistent configuration
  * Masters info leakfix
  * Refactor redis_sock_read_bulk_reply
  * Remove unused parameter lazy_connect from redis_sock_create
  * Remove useless ZEND_ACC_[C|D]TOR.
  * Documentation improvements
- Added additional settings to redis.ini
* Fri Nov 30 2018 Илья Индиго <ilya@ilya.pp.ua>
- Update to 4.2.0
  * https://pecl.php.net/package-changelog.php?package=redis&release=4.2.0
  * Optimize close method.
  * Prevent potential infinite loop for sessions.
  * Fix coverty warnings.
  * Fix session memory leaks.
  * Fix XCLAIM on 32-bit installs.
  * Build warning fixes.
  * Fix incorrect arginfo for `Redis::sRem` and `Redis::multi`.
  * Update STREAM API to handle STATUS -> BULK reply change.
  * Treat a -1 response from cluster_check_response as a timeout.
  * Use a ZSET insted of SET for EVAL tests.
  * Missing space between command and args.
  * Streams API.
  * Reset the socket after a timeout to make sure no wrong data is received.
  * Modify session testing logic.
  * Allow '-' and '+' arguments and add tests for zLexCount and zRemRangeByLex.
  * Fix printf format warnings.
  * Session module is required.
  * Set default values for ini entries.
  * Display ini entries in output of phpinfo.
  * Persistant connections can be closed via close method + change reconnection logic.
  * Documentation improvements.
* Thu Aug 16 2018 ilya@ilya.pp.ua
- Update to 4.1.1
  * https://pecl.php.net/package-changelog.php?package=redis&release=4.1.1
  * Fix arginfo for Redis::set method.
  * Fix compression in RedisCluster.
  * Fix TravisCI builds.
  * Highlight php codes in documentation.
* Fri Jul 13 2018 ilya@ilya.pp.ua
- Update to 4.1.0
  * https://pecl.php.net/package-changelog.php?package=redis&release=4.1.0
  * Add callbacks validate_sid and update_timestamp to session handler.
  * Call cluster_disconnect before destroying cluster object.
  * Bulk strings can be zero length.
  * Handle async parameter for flushDb and flushAll.
  * Split INSTALL and add more instructions.
  * Only the first arg of connect and pconnect is required.
  * Add session locking functionality.
  * Fix compression in RedisCluster.
  * Refactor geo* commands + documentation improvements.
* Fri Apr 27 2018 ilya@ilya.pp.ua
- Update to 4.0.2
  * https://pecl.php.net/package-changelog.php?package=redis&release=4.0.2
  * Fix of exists method to take multiple keys and return integer value.
* Fri Apr 20 2018 jweberhofer@weberhofer.at
- Update to 4.0.1
  * Fix arginfo for connect/pconnect issue
  * Don't leak a ZVAL
  * Fix config.m4 for lzf
  * Updates EXISTS documentation and notes change in 4.0.0
  * Fix typo in notes
* Mon Mar 19 2018 ilya@ilya.pp.ua
- Update to 4.0.0
  * https://pecl.php.net/package-changelog.php?package=redis&release=4.0.0
  * Add proper ARGINFO for all methods.
  * Let EXISTS take multiple keys.
  * Use zend_string as returning value for ra_extract_key and ra_call_extractor.
  * Implement SWAPDB and UNLINK commands.
  * Return real connection error as exception.
  * Disallow using empty string as session name.
  * Use zend_string for storing auth and prefix members.
  * The element of z_seeds may be a reference on php7.
  * Avoid connection in helper methods.
  * Add tcp_keepalive option to redis sock.
  * More robust GEORADIUS COUNT validation.
  * Add LZF compression (experimental).
  * Allow to use empty string as persistant_id.
  * Don't use convert_to_string in redis_hmget_cmd.
  * Allow mixing MULTI and PIPELINE modes (experimental).
  * PHP >=7.3.0 uses zend_string to store `php_url` elements.
  * Documentation improvements.
* Thu Mar  8 2018 ilya@ilya.pp.ua
- Remove %%configure/make duplicates.
- Add %%licence macros.
* Tue Jan 30 2018 crrodriguez@opensuse.org
- Build with hidden visibility, only a few symbols must be
  exported, those are marked with default visibility in PHP core
  headers.
* Thu Jan  4 2018 ilya@ilya.pp.ua
- Update to 3.1.6
  * ChangeLog https://pecl.php.net/package-changelog.php?package=redis&release=3.1.6
  * Fix of RedisArray distributor hashing function which was broken in 3.1.4.
  * Fix RedisCluster constructor with PHP 7 strict scalar type.
  * Allow to use empty string as persistant_id.
  * Fix cluster_init_seeds.
  * Fix z_seeds may be a reference.
  * PHP >=7.3 uses zend_string for php_url elements.
* Sun Oct  8 2017 ilya@ilya.pp.ua
- Update to 3.1.4
  * ChangeLog https://pecl.php.net/package-changelog.php?package=redis&release=3.1.4
  * Allow mixing MULTI and PIPELINE modes (experimental).
  * Added integration for coverty static analysis and fixed several warnings.
  * Fixed link to redis cluster documentation.
  * Remove unused PHP_RINIT and PHP_RSHUTDOWN functions.
  * Removed duplicate HGET in redis array hash table, formatting.
  * Treat NULL bulk as success for session read.
  * Refactor redis_send_discard.
  * Updated runtime exception handling.
  * Added a github issue template.
  * Initialize gc member of zend_string.
  * Fix valgrind warnings.
  * Fix php5/php7 compatibility layer.
  * Fix typo in README.markdown.
  * Improve redis array rehash.
  * Change redis array pure_cmds from zval to hashtable.
  * Don't try to set TCP_NODELAY on a unix socket and don't warn on multiple calls to pipeline.
  * Use zend_string rather than char* for various context fields.
  * Various other library fixes.
* Wed Aug  2 2017 tchvatal@suse.com
- Remove the php5 packages as the php5 language is being removed
* Wed Jul 19 2017 ilya@ilya.pp.ua
- Update to 3.1.3
  * ChangeLog https://pecl.php.net/package-changelog.php?package=redis&release=3.1.3
* Mon Jul 10 2017 ilya@ilya.pp.ua
- Add config file redis.ini
- Format spec-file to macro style
* Tue Jun 27 2017 jweberhofer@weberhofer.at
- Upgraded to version 3.1.2
  * RedisArray segfault fix [564ce3] (Pavlo Yatsukhnenko)
  * Small memory leak fix [645888b] (Mike Grunder)
  * Segfault fix when recreating RedisCluster objects [abf7d4] (Michael Grunder)
  * Fix for RedisCluster bulk response parsing [4121c4] (Alberto Fern?ndez)
  * Re allow single array for sInterStore [6ef0c2, d01966] (Michael Grunder)
  * Better TravisCI integration [4fd2f6] (Pavlo Yatsukhnenko)
* Sat Feb 18 2017 jweberhofer@weberhofer.at
- Upgraded to version 3.1.1
  This release contains mostly fixes for issues introduced when merging
  the php 5 and 7 codebase into a single branch.
  * Fixed a segfault in igbinary serialization (@yatsukhnenko)
  * Restore 2.2.8/3.0.0 functionality to distinguish between an error
    and simply empty session data. (@remicollet)
  * Fix double to string conversion function (@yatsukhnenko)
  * Use PHP_FE_END definition when available (@remicollet)
  * Fixed various 'static function declared but not used' warnings
  * Fixes to various calls which were typecasting pointers to the wrong size. (@remicollet)
  * Additional test updates for 32 bit systems (@remicollet)
  * ARM rounding issue in tests (@remicollet)
  * Use new zend_list_close instead of zend_list_delete when reconnecting.
  * Refactoring of redis_boolean_response_impl and redis_sock_write (@yatsukhnenko)
  * Added php session unit test (@yatsukhnenko)
  * Added explicit module dependancy for igbinary (@remicollet)
  * Added phpinfo serialization information (@remicollet)
- Version 3.1.0
  In this version of phpredis codebase was unified to work with all versions of php.
  Also many bug fixes and some improvements has been made.
- Improvements
  * Support the client to Redis Cluster just having one master (andyli) [892e5646]
  * Allow both long and strings that are longs for zrangebyscore offset/limit (Michael Grunder) [bdcdd2aa]
  * Process NX|XX, CH and INCR options in zAdd command (Pavlo Yatsukhnenko) [71c9f7c8]
- Fixes
  * Fix incrby/decrby for large integers (Michael Grunder) [3a12758a]
  * Use static declarations for spl_ce_RuntimeException decl (Jeremy Mikola) [a9857d69]
  * Fixed method call problem causes session handler to display two times (ZiHang Gao) [24f86c49]
  * psetex method returns '+OK' on success, not true (sitri@ndxbn) [afcd8445]
  * Fix integer overflow for long (>32bit) increments in hIncrBy (iyesin) [58e1d799]
  * Move zend_object handler to the end (Michael Grunder) [34107966]
  * Using setOption on redis array causes immediate connection (Pavlo Yatsukhnenko) [f1a85b38]
* Sun Jan 29 2017 jweberhofer@weberhofer.at
- Provide php-redis as php5 and php7 can't be installed together
* Tue Jan 10 2017 jweberhofer@weberhofer.at
- Updated to version 3.0.0 - no changelog provided
* Tue Mar  8 2016 danimo@owncloud.com
- Update build from php7 branch
